@@ -4,7 +4,7 @@ use warnings;
 
 package Path::Iterator::Rule;
 # ABSTRACT: Iterative, recursive file finder
-our $VERSION = '1.013';
+our $VERSION = '1.014';
 
 # Register warnings category
 use warnings::register;
@@ -752,7 +752,7 @@ Path::Iterator::Rule - Iterative, recursive file finder
 
 =head1 VERSION
 
-version 1.013
+version 1.014
 
 =head1 SYNOPSIS
 
@@ -823,6 +823,10 @@ provides an API for extensions
 As a convenience, the L<PIR> module is an empty subclass of this one
 that is less arduous to type for one-liners.
 
+B<Note>: paths are constructed with unix-style forward-slashes for
+efficiency rather than using L<File::Spec>.  If proper path separators are
+needed, call L<canonpath|File::Spec/canonpath> on the search results.
+
 =head1 USAGE
 
 =head2 Constructors
